<?php
/*  
Plugin Name: Instagrate to WordPress
Plugin URI: http://www.polevaultweb.com/plugins/instagrate-to-wordpress/ 
Description: Plugin for automatic posting of Instagram images into a WordPress blog.
Author: polevaultweb 
Version: 1.1.2
Author URI: http://www.polevaultweb.com/

Copyright 2012  polevaultweb  (email : info@polevaultweb.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as 
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/

//plugin version
define( 'ITW_PLUGIN_VERSION', '1.1.2');
define( 'ITW_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'ITW_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
define( 'ITW_PLUGIN_BASE', plugin_basename( __FILE__ ) );
define( 'ITW_PLUGIN_SETTINGS', 'instagratetowordpress');

define( 'RETURN_URI', strtolower(plugin_dir_url( __FILE__ ).'php/callback.php'));

require_once ITW_PLUGIN_PATH.'php/instagram.php';

if (!class_exists("instagrate_to_wordpress")) {

	
	class instagrate_to_wordpress {
			
		/* Plugin loading method */
		public static function load_plugin() {
			
			//cache fix
			session_cache_limiter( FALSE );
			session_start(); 
						
			//settings menu
			add_action('admin_menu',get_class()  . '::register_settings_menu' );
			//settings link
			add_filter('plugin_action_links', get_class()  . '::register_settings_link', 10, 2 );
			//styles and scripts
			add_action('admin_init', get_class()  . '::register_styles');
			//register upgrade check function
			add_action('admin_init', get_class()  . '::upgrade_check');
			//register uninstall hook
			register_uninstall_hook(__FILE__, 'plugin_uninstall');
			
			//add notices for prechecks
			add_action('admin_notices', get_class()  . '::plugin_admin_notice');
			
			//register the listener function
			add_action( 'template_redirect', get_class()  . '::auto_post_images');	
			
			
	 	
		}
		
		/* Add menu item for plugin to Settings Menu */
		public static function register_settings_menu() {  
   		  			
   			add_options_page( 'Instagrate to WordPress', 'Instagrate to WordPress', 1, ITW_PLUGIN_SETTINGS, get_class() . '::settings_page' );
	  				
		}
		
		/* Add settings link to Plugin page */
		public static function register_settings_link($links, $file) {  
   		  		
			static $this_plugin;
				if (!$this_plugin) $this_plugin = ITW_PLUGIN_BASE;
				 
				if ($file == $this_plugin){
				$settings_link = '<a href="options-general.php?page='.ITW_PLUGIN_SETTINGS.'">' . __('Settings', ITW_PLUGIN_SETTINGS) . '</a>';
				array_unshift( $links, $settings_link );
			}
			return $links;
			
		}
		
		/* Register custom stylesheets and script files */
		public static function register_styles() {
		 
			if (isset($_GET['page']) && $_GET['page'] == ITW_PLUGIN_SETTINGS) {
		 
				//register styles
				wp_register_style( 'itw_style', ITW_PLUGIN_URL . 'css/style.css');
				
				//enqueue styles	
				wp_enqueue_style('itw_style' );
				wp_enqueue_style('dashboard');
				//enqueue scripts
				wp_enqueue_script('dashboard');
			
			}
		
		}
		
		/* Register custom upgrade check function */
		public static function upgrade_check() {
		
			$saved_version = get_option( 'itw_version' );
			$current_version = isset($saved_version) ? $saved_version : 0;

			if ( version_compare( $current_version, ITW_PLUGIN_VERSION, '==' ) ) {
				return;
			}
				
			//specific version checks on upgrade
			if ( version_compare( $current_version, '1.1.0', '<' ) ) {
			
				//set new defaults
				
				//set image link to true
				update_option('itw_imagelink', true);
				//set debug mode to false
				update_option('itw_debugmode', false);
				//set image saving
				update_option('itw_imagesave', 'link');	 
				//set image featured option
				update_option('itw_imagefeat', 'nofeat');	
				//set image date
				update_option('itw_post_date', 'now');	
				//set post format
				update_option('itw_postformat', 'Standard');	
				//make sure the processing transient is set and reset for new and beta testers
				set_transient('itw_posting' ,'done', 60*5);
			}
			
			//specific version checks on upgrade
			if ( version_compare( $current_version, '1.1.1', '<' ) ) {
			
				//new defaults
				
				//set post status
				update_option('itw_poststatus', 'publish');
			
			}
			
							
			//update the database version
			update_option( 'itw_version', ITW_PLUGIN_VERSION );
		
		}
		
		/* Register custom uninstall function */
		public static function plugin_uninstall() {
		
			//delete options
			delete_option('itw_accesstoken');
			delete_option('itw_username');
			delete_option('itw_userid');
			delete_option('itw_manuallstid');
			delete_option('itw_configured');
			delete_option('itw_manuallstid');
			delete_option('itw_imagesize');
			delete_option('itw_imageclass');
			delete_option('itw_imagelink');
			delete_option('itw_postcats');
			delete_option('itw_postauthor');
			delete_option('itw_postformat');
			delete_option('itw_post_date');
			delete_option('itw_customtitle');
			delete_option('itw_customtext');
			delete_option('itw_pluginlink');
			delete_option('itw_imagesave');
			delete_option('itw_imagefeat');
			delete_option('itw_debugmode');
			delete_option('itw_poststatus');
			
			//remove hooks
			remove_action( 'template_redirect', get_class()  . '::auto_post_images');
		
		}
		
		/* Display check for user to make sure a blog page is selected */
		public static function plugin_admin_notice(){
			
			if (isset($_GET['page']) && $_GET['page'] == ITW_PLUGIN_SETTINGS) {
				
				if ('page' == get_option('show_on_front')) {
			
					if ( 0 == get_option('page_for_posts') ) {
					
						echo '<div class="updated">
								<p>You must select a page to display your posts in <a href="'.home_url().'/wp-admin/options-reading.php">Settings -> Reading</a></p>
							</div>';
					
					}
 
				}	
					 
			}
		}

		/* Plugin debug functions */
		public static function plugin_debug_write($string) {
		
			//Set the filepath and filename for the WP Hook Sniff text report */
			$itw_debug_path_file = ITW_PLUGIN_PATH . "debug.txt";
			
			$fh = fopen( $itw_debug_path_file, "a" ) or die( "can't open file" );
			fwrite( $fh, $string );
			fclose( $fh );
			
		}
		
		/* Register default options for plugin link, author, category, post type */
		public static function set_default_options($lastid) {
			
			
			//update manual last id
			//$manuallstid= '';
			//$manuallstid= get_option('itw_manuallstid');
			
			if (!get_option('itw_manuallstid'))
			{
				update_option('itw_manuallstid', $lastid);
			}
		
			$configured= '';
			$configured= get_option('itw_configured');
						
			if ($configured != 'Installed') {
			
				
				//update_option('itw_manuallstid', $lastid);
				
							
				//Set plugin link to false
				update_option('itw_pluginlink', false);
				
				//set image link to true
				update_option('itw_imagelink', false);
				
				//set debug mode as off by default
				update_option('itw_debugmode', false);
				
				//set image saving
				update_option('itw_imagesave', 'link');
				 
				//set image featured option
				update_option('itw_imagefeat', 'nofeat');
				
				//set post format
				update_option('itw_postformat', 'Standard');
				
				//set post status
				update_option('itw_poststatus', 'publish');
						
				//Set author
				$current_user =  wp_get_current_user();
				$username = $current_user->ID;
				
				//print $username;
				update_option('itw_postauthor', $username);
				
				//set cats as earliest cat id
				$args = array(
							'type'                     => 'post',
							'child_of'                 => 0,
							'parent'                   => '',
							'orderby'                  => 'id',
							'order'                    => 'ASC',
							'hide_empty'               => 1,
							'hierarchical'             => 1,
							'exclude'                  => '',
							'include'                  => '',
							'number'                   => 1,
							'taxonomy'                 => 'category',
							'pad_counts'               => false );
	
				$categories = get_categories( $args );
				foreach($categories as $cats) {
				
				$cat = $cats->cat_ID;
										
				}
				update_option('itw_postcats', $cat);
				
				//set post date 
				update_option('itw_post_date','now');
				

			}
		
		}
		
		/* Instagram post feed array */
		public static function get_images() {
		
			$access_token = false;
			
			if(!$access_token ):
			
				//get current last id
				$manuallstid = get_option('itw_manuallstid');
				//get access token
				$access_token = get_option('itw_accesstoken');
				//get userid
				$userid = get_option('itw_userid');
				
				$instagram = new itw_Instagram(CLIENT_ID, CLIENT_SECRET, $access_token);
				
				try {
						
					$params =  array('min_id' => $manuallstid);
				
					$data = $instagram->get('users/'.$userid.'/media/recent', $params);
					//var_dump($data);
				
				
					//echo $manuallstid;
					$images = array();
					
					if($data->meta->code == 200):
					
		
						foreach($data->data as $item):
													
									$images[] = array(
										"id" => $item->id,
										"title" => (isset($item->caption->text)?filter_var($item->caption->text, FILTER_SANITIZE_STRING):""),
										"image_small" => $item->images->thumbnail->url,
										"image_middle" => $item->images->low_resolution->url,
										"image_large" => $item->images->standard_resolution->url,
										"created" => $item->created_time
									);				
					
						endforeach;
					
					endif;
					
					$orderByDate = array();
					
					//order array by earliest image
					foreach ($images as $key => $row) {
						$orderByDate[$key]  = strtotime($row['created']);
					}

					array_multisort($orderByDate, SORT_ASC, $images);
					
			
					return $images;
				
				
				} catch(InstagramApiError $e) {
						
						update_option('itw_accesstoken', '');
						update_option('itw_username', '');
						update_option('itw_userid', '');
						update_option('itw_manuallstid', '');
					
				}
	
			endif;
	
		}
		
		/* Get last ID of image array */
		public static function get_last_id($data) {
			
			$images = array();
			
			foreach($data->data as $item):
										
						$images[] = array(
							"id" => $item->id,
							"title" => (isset($item->caption->text)?filter_var($item->caption->text, FILTER_SANITIZE_STRING):""),
							"image_small" => $item->images->thumbnail->url,
							"image_middle" => $item->images->low_resolution->url,
							"image_large" => $item->images->standard_resolution->url
						);				
		
			endforeach;
			
			return $images[0]["id"];
		
		}

		
		
		/* Main function to post Instagram images */
		public static function auto_post_images() {
		
		
			//check if date is Instagram or not
			$date_check = get_option('itw_post_date');
			$debugmode = get_option('itw_debugmode');
			
			if ($date_check == false) {$date_check = 'now';  }
			
			//debug
			$debug = "------------------------------------------------------------------------------------------------------------------------------------------\n";
			$debug .= "Instagrate to WordPress - Plugin Debug Output: " . Date( DATE_RFC822 ) . "\n";
			$debug .= "PAGE LOAD " . Date( DATE_RFC822 ) . "\n";
			$debug .= "------------------------------------------------------------------------------------------------------------------------------------------\n";
			
			$debug .= "Home page is: ".get_home_template(). "\n";
			$debug .= "Current page is: ".get_page_template(). "\n";
			$debug .= "------------------------------------------------------------------------------------------------------------------------------------------\n";
			
			//check if page is blog page - only run
			if (is_home()) {
			
				
				$debug .= "--START Blog is_home() check TRUE ". Date( DATE_RFC822 ) . "\n";
				$debug .= "--START Auto post function START ". Date( DATE_RFC822 ) . "\n";
				$debug .= "--Marker: ". get_transient( 'itw_posting' )  . "\n";
			
				// Check if auto_post_process has NOT already been 
				$marker = get_transient('itw_posting');
				
				$last_run = get_option('itw_last_run');
				
				if ($last_run === false) {
					
					$last_run = 0;
				}
				
				if (( false === $marker  || $marker != 'processing' ) && ( time() - $last_run > 60 )) {
				
					
					try {
					
						//set cache transient to mark as processing
						set_transient('itw_posting' ,'processing', 60*5);
						
						$manuallstid = get_option('itw_manuallstid');
						
						//debug
						$debug .= "----START Auto post function: ". Date( DATE_RFC822 ) . "\n";
						$debug .= "----Marker: ". get_transient( 'itw_posting' )  . "\n";
						$debug .= "----Last ID:".$manuallstid."\n";
						
								
						$images = self::get_images();
						//$images = array_reverse($images_orig);
						//get count of array of images
						$count = sizeof($images);
						
						//debug
						$debug .= "----Count of Images: ".$count."\n";
						
						
						//set counter
						$last_id = 0;
						
						//debug
						$debug .= "------START Auto post function Image Loop:  ". Date( DATE_RFC822 ) . "\n";
						
						//loop through array to get image data
						for ($i = 0; $i < $count; $i++) {
							
							//debug
							$debug .= "--------".$i.": Loop:  ". Date( DATE_RFC822 ) . "\n";
							
							//Don't include image of $manuallstid
							if ($images[$i]["id"] != $manuallstid) {
								
								//debug
								$debug .= "--------Image Id:".$images[$i]["id"]." Does not equal Last Id:".$manuallstid."\n";
							
								// only allow the posting to happen if image timestamp is 2 minutes ago, to stop double posting through API
								if ((time() - $images[$i]["created"]) > 120) {
									
									//get image variables
									$title = $images[$i]["title"];
									$image = $images[$i]["image_large"];
									
									$last_id = $images[$i]["id"];
									
									//debug
									$debug .= "----------Auto post function Ready to Post:  ". Date( DATE_RFC822 ) . "\n";
									$debug .= "----------Title: ".$title."\n";
									$debug .= "----------Image: ".$image."\n";
									
									
									if ($date_check == 'instagram') {
									
										$post_date = $images[$i]["created"];
										$post_date = date('Y-m-d H:i:s',$post_date);
										$post_date_gmt  = $post_date;
									
									} else {
									
										$post_date_gmt = date('Y-m-d H:i:s',current_time('timestamp',1) - (($count-$i) * 20));
										$post_date = date('Y-m-d H:i:s',current_time('timestamp',0) - (($count-$i) * 20));
	
									}
									
									//post new images to wordpress
									$debug .= self::blog_post($title,$image, $post_date,$post_date_gmt);
									
									

								}
								else {
									
									//debug
									$debug .= "------END Auto post function: ". Date( DATE_RFC822 ) . "\n";
									$debug .= "------Image created within 2 minutes of posting loop\n";
									$debug .= "------Image Created:".$images[$i]["created"] ."\n";
									$debug .= "------Posting Time:".time() ."\n";
																
									//break out of image loop
									break;
								}
							
							} else {
							
									//transient exists already posting ignore
									//debug
									//debug
									$debug .= "--------".$images[$i]["id"]." == ". $manuallstid . "\n";
									$debug .= "--------END Auto post function STOP as last ID already posted ". Date( DATE_RFC822 ) . "\n";
														
							}
							
							//set last run timestamp
							update_option('itw_last_run', time());
						
						}
						
										
						if ($last_id != 0)
						{
							//update last id field in database with last id of image added
											
							//echo '<h1>'.$images[0]["id"].'</h1>';
							//debug
							$debug .= "----------START End loop write Last Image ID: ". Date( DATE_RFC822 ) . "\n";
							$debug .= "----------First Image ID of Loop: ".$images[0]["id"]. "\n";
							$debug .= "----------Current Last ID: ".get_option('itw_manuallstid').  "\n";
							$debug .= "----------Writing Last ID ". Date( DATE_RFC822 ) . "\n";
							//update_option('itw_manuallstid', $images[0]["id"]);
							update_option('itw_manuallstid', $last_id);
							$debug .= "----------Written Last ID: ".get_option('itw_manuallstid'). "\n";
						}
						
					}
					
					catch(Exception $e){
					
					//var_dump $e;
					
					}
											
					//clear processing marker
					set_transient('itw_posting' ,'done', 60*5);
					
					//debug
					$debug .= "------END Auto post function Image Loop:  ". Date( DATE_RFC822 ) . "\n";
					$debug .= "------Marker:  ". get_transient( 'itw_posting' )  . "\n";
				
				} else 	{
				
				//transient exists already posting ignore
				//debug

				$debug .= "----END Auto post function failed as Transient Exists: ".$marker." (Already posting) ". Date( DATE_RFC822 ) . "\n";
				$debug .= "----END Auto post function failed as started less than a minute since last run - ". $last_run . " Now - ".time()."\n";
				
				
				}
				
				
				//debug
				$debug .= "--END Auto post function END ". Date( DATE_RFC822 ) . "\n";
				
				
				
			} else {
				
				//not blog page so don't run
				//debug
				$debug .= "--END Blog is_home() check FALSE ". Date( DATE_RFC822 ) . "\n";
			
			}
			
			if ($debugmode) {
				
				self::plugin_debug_write($debug);
			
			}
			
					
		}
		
		/* Log out of instagram */
		public static function log_out()
		{	
			//ob_start();
			
			//clear cookies for instagram credentials
			//setcookie ("sessionid", "", time() - 3600, "/","instagram.com");			
			
			//Clear user settings in db
			session_destroy ();
			
			update_option('itw_accesstoken', '');
			update_option('itw_username', '');
			update_option('itw_userid', '');
			update_option('itw_manuallstid', '');
			
			
		
		}
		
		/* Attach an image to the media library */
		function attach_image($url, $postid) {
		
			require_once(ABSPATH . "wp-admin" . '/includes/image.php');
			require_once(ABSPATH . "wp-admin" . '/includes/file.php');
			require_once(ABSPATH . "wp-admin" . '/includes/media.php');


			$tmp = download_url( $url );
			$file_array = array(
				'name' => basename( $url ),
				'tmp_name' => $tmp
			);
			
			// Check for download errors
			if ( is_wp_error( $tmp ) ) {
				@unlink( $file_array[ 'tmp_name' ] );
				return $tmp;
			}

			$id = media_handle_sideload( $file_array, $postid );
			// Check for handle sideload errors.
		 
			if ( is_wp_error( $id ) ) {
				@unlink( $file_array['tmp_name'] );
				return $id;
			} else {
				
				return $id;
				
			}
		}

		/* Remove the querystring from a URL */
		function strip_querysting($url) {

			if (strpos($url,'?') !== false) {
				$url = substr($url,0,strpos($url, '?'));
			}
			return $url;
			
		}
		
		/* Posting to WordPress */
		public static function blog_post($post_title, $post_image,$post_date, $post_date_gmt ) {

			
			$debug .= "------------START Blog_post ". Date( DATE_RFC822 ) . "\n";
		
			
			$orig_title = $post_title;
			
			$imagesize = get_option('itw_imagesize');
			$imageclass = get_option('itw_imageclass');
			$postcats = get_option('itw_postcats');
			$postauthor = get_option('itw_postauthor');
			$postformat = get_option('itw_postformat');
			$customtitle = get_option('itw_customtitle');
			$customtext = get_option('itw_customtext');
			$pluginlink = get_option('itw_pluginlink');
			$imagelink = get_option('itw_imagelink');
			$imagesave = get_option('itw_imagesave');
			$imagefeat = get_option('itw_imagefeat');	
			$poststatus = get_option('itw_poststatus');			
	
			//Image class
			if ($imageclass != '')
			{
				$imageclass = 'class="'.$imageclass.'" ';
			}
			
			//Image size
			if ($imagesize != '')
			{
				$imagesize = 'width="'.$imagesize.'" height="'.$imagesize.'" ';
			}
			
			//Custom Post Title
			if ($customtitle != '' ){
			
				$pos = strpos(strtolower($customtitle),'%%title%%');
				if($pos === false) {
					
					//no %%title%% found so put instagram title after custom title
					$post_title = $customtitle;;
				
				}
				else {
				 	
				 	//%%title%% found so replace it with instagram title
				 	$post_title = str_replace("%%title%%", $post_title, $customtitle);
				}
		
			}
			
				// Create post object
		  	$my_post = array(
				 'post_title' => $post_title,
				 'post_content' => '',
				 'post_author' => $postauthor,
				 'post_category' => array($postcats),
				 'post_status' => $poststatus,
				 'post_date' => $post_date, //The time post was made.
				 'post_date_gmt' =>  $post_date_gmt //[ Y-m-d H:i:s ] //The time post was made, in GMT.
		 	 );
			 
			 	 
			// Insert the post into the database
		  	$new_post = wp_insert_post( $my_post );
			
			//image settings
			if ($imagesave == 'link') {
				//link to instagram image
				$image = '<img src="'.$post_image.'" '.$imageclass.' alt="'.$post_title.'" '.$imagesize.' />';
			
			} else {
				
				//put image from instagram into wordpress media library and link to it.
				$post_image = self::strip_querysting($post_image);
				//load into media library
				$attach_id = self::attach_image($post_image,$new_post);
				//get new shot image url from media attachment
				$post_image = wp_get_attachment_url($attach_id);
				
				$image = '<img src="'.$post_image.'" '.$imageclass.' alt="'.$post_title.'" '.$imagesize.' />';				
				
				//featured image settings
				if ($imagefeat == 'featonly') {
				
					//featured only - only set as featured
					$image = '';
			
				}
				
			}
			
			//image link
			if ($imagelink && $image != '' ) {
				//add link to instagram shot
				$image = '<a href="'.$post_image.'" title="'.$post_title.'" >'.$image.'</a>';
			}			
					
			
			if ($customtext != '' ){
			
				//check if %%image%% has been used 
				$pos = strpos(strtolower($customtext),'%%image%%');
				if($pos === false) {
					
					//no %%image%% found so put instagram image after custom text
					$post_body = $customtext.'<br/>'.$image;
				
				}
				else {
				 	
				 	//%%image%% found so replace it with instagram title
				 	$post_body = str_replace("%%image%%", '<br/>'.$image.'<br/>', $customtext);
				}
				
				//check if %%title%% has been used
				$pos = strpos(strtolower($customtext),'%%title%%');
				if($pos === false) {
					
					//no %%title%% found so put instagram title after custom title
					$post_body = $post_body;
				
				}
				else {
				 	
				 	//%%title%% found so replace it with instagram title
				 	$post_body = str_replace("%%title%%", $orig_title, $post_body);
				 
				}

			} else { 
			
				//no custom text just plain old image
				$post_body = $image;
			}
			
			//Plugin link credit
			if ($pluginlink == true ) {

				$post_body  = $post_body.' <br/><small>Posted by <a href="http://wordpress.org/extend/plugins/instagrate-to-wordpress/">Instagrate to WordPress</a></small>';	
			}
			
			$post_body = "<!-- This post is created by Instagrate to WordPress, a WordPress Plugin by polevaultweb.com - http://www.polevaultweb.com/plugins/instagrate-to-wordpress/ -->".$post_body;
					
				
			$debug .= "--------------START wp_insert_post ". Date( DATE_RFC822 ) . "\n";
			
			
			// Update post with content
			$update_post = array();
			$update_post['ID'] = $new_post;
			$update_post['post_status'] = $poststatus;
			$update_post['post_content'] = $post_body;

			// Update the post into the database
			wp_update_post( $update_post );
			
			//apply format if not standard
			if ($postformat != 'Standard') {
				set_post_format( $new_post , $postformat);
			}
			
			//apply featured image if needed
			if ($imagefeat != 'nofeat' && $imagesave != 'link') {
			
				add_post_meta($new_post, '_thumbnail_id', $attach_id);
				
			}
			
				
					
			$debug .= "--------------END wp_insert_post ". Date( DATE_RFC822 ) . "\n";
			

			$debug .= "------------END blog_post". Date( DATE_RFC822 ) . "\n";
			
			
			return $debug;
			
		}	

			
		
		/* Plugin Settings page and settings data */
		public static function settings_page() { 
		
		
			if(isset($_POST['itw_logout']) && $_POST['itw_logout'] == 'Y'){
							
					self::log_out();
							
			}
				
			$oldplugin ='instapost-press/instapost-press.php';
			
			
			
			if(is_plugin_active($oldplugin))
			{
				$oldplugintest = 1;
			
			}
			else {
							
				$instagram = new itw_Instagram(CLIENT_ID, CLIENT_SECRET,null);
				$msg_class = 'itw_connected';
			
				//session_cache_limiter( TRUE );			
				if (isset($_SESSION['access_token'])) {
				
					update_option('itw_accesstoken', $_SESSION['access_token']);
					update_option('itw_username', $_SESSION['username']);
					update_option('itw_userid', $_SESSION['userid']);
				
				
					unset($_SESSION['access_token']);
					unset($_SESSION['username']);
					unset($_SESSION['userid']);
				
				}
				elseif (isset($_SESSION['error_reason'])) {
				
					$msg = 'You did not authorise the plugin to access your Instagram account. Maybe try again - ';
					$msg_class = 'itw_disconnected';
					
					$loginUrl = $instagram->authorizeUrl(REDIRECT_URI.'?return_uri='.htmlentities(RETURN_URI));
					
					
					unset($_SESSION['error_reason']);
					unset($_SESSION['error_description']);
					
					update_option('itw_accesstoken', '');
					update_option('itw_username', '');
					update_option('itw_userid', '');
					update_option('itw_manuallstid', '');
				}
			
				if ($msg_class != 'itw_disconnected')
				{
				
				$access_token = get_option('itw_accesstoken');
				$instagram = new itw_Instagram(CLIENT_ID, CLIENT_SECRET, $access_token);
			
				//echo $access_token;
				
				if(!$access_token){
					// no access token in db
					
					$msg = 'Please login securely to Instagram to authorise the plugin - ';
					$msg_class = 'itw_setup';	
					$loginUrl = $instagram->authorizeUrl(REDIRECT_URI.'?return_uri='.htmlentities(RETURN_URI));
				
				
				} else {   

					//logged in
					try {
					
						$username = get_option('itw_username');
						$userid = get_option('itw_userid');
						$msg = $username;
						$msg_class = 'itw_connected';
						
						
						$feed = $instagram->get('users/'.$userid.'/media/recent');
						
						if($feed->meta->code == 200): 
						//var_dump($feed);
						
							if(isset($_POST['itw_hidden']) && $_POST['itw_hidden'] == 'Y') {
														
								update_option('itw_configured', 'Installed');
								
								$manuallstid  = $_POST['itw_manuallstid'];
								update_option('itw_manuallstid', $manuallstid);
								
								$imagesize  = $_POST['itw_imagesize'];
								update_option('itw_imagesize', $imagesize);
								
								$imageclass  = $_POST['itw_imageclass'];
								update_option('itw_imageclass', $imageclass);
								
								$imagelink  = $_POST['itw_imagelink'];
								update_option('itw_imagelink', $imagelink);
															
								$postcats  = $_POST['itw_postcats'];
								update_option('itw_postcats', $postcats);
								
								$postauthor  = $_POST['itw_postauthor'];
								update_option('itw_postauthor', $postauthor);
								
								$postformat  = $_POST['itw_postformat'];
								update_option('itw_postformat', $postformat);
								
								$postdate  = $_POST['itw_post_date'];
								update_option('itw_post_date', $postdate);
								
								$customtitle  = $_POST['itw_customtitle'];
								update_option('itw_customtitle', $customtitle);
								
								$customtext  = $_POST['itw_customtext'];
								update_option('itw_customtext', $customtext);
								
								$imagesave  = $_POST['itw_imagesave'];
								update_option('itw_imagesave', $imagesave);
								
								$imagefeat  = $_POST['itw_imagefeat'];
								update_option('itw_imagefeat', $imagefeat);
								
								
								$pluginlink  = $_POST['itw_pluginlink'];
								update_option('itw_pluginlink', $pluginlink);
								
								$debugmode  = $_POST['itw_debugmode'];
								update_option('itw_debugmode', $debugmode);
								
								$poststatus  = $_POST['itw_poststatus'];
								update_option('itw_poststatus', $poststatus);
									
								?>
								
								<div class="itw_saved"><p><?php _e('Plugin settings saved!' ); ?></p></div>
								<div class="clear"></div>
								<?php
							} else {
									
									
								//set defaults if need
								$lastid = self::get_last_id($feed);
								self::set_default_options($lastid);
							
								$manuallstid = get_option('itw_manuallstid');
								//echo $manuallstid;
								$imagesize = get_option('itw_imagesize');
								$imageclass = get_option('itw_imageclass');
								$imagelink = get_option('itw_imagelink');
								//$customposttype = get_option('itw_customposttype');
								$postcats = get_option('itw_postcats');
								$postauthor = get_option('itw_postauthor');
								$postformat = get_option('itw_postformat');
								$postdate =  get_option('itw_post_date');
								$customtitle = get_option('itw_customtitle');
								$customtext = get_option('itw_customtext');
								$pluginlink = get_option('itw_pluginlink');
								$imagesave = get_option('itw_imagesave');
								$imagefeat = get_option('itw_imagefeat');
										
								$debugmode = get_option('itw_debugmode');
								$poststatus = get_option('itw_poststatus');
								
								
							}
							
						else:
						
							$msg = 'Error: '.$feed->meta->error_type.' - '.$feed->meta->error_message;
							$msg_class = 'itw_disconnected';
							$loginUrl = 'hide';						
						
						endif;
						
						
						
						//update_option('itw_configured', '');
					
						
						} catch(InstagramApiError $e) {
						
						update_option('itw_accesstoken', '');
						update_option('itw_username', '');
						update_option('itw_userid', '');
						update_option('itw_manuallstid', '');
					
						$msg = 'The Instagram Authorisation token has expired - ';
						$msg_class = 'itw_disconnected';
						$loginUrl = $instagram->authorizeUrl(REDIRECT_URI.'?return_uri='.htmlentities(RETURN_URI));
						//die($e->getMessage());
					}
				}
				}
			
			}
			
			
		
			
			?>
			
			<!-- BEGIN Wrap -->
			<div class="wrap">
				<div class="h2_left">
					<h2 class="instagrate_logo">Instagrate to WordPress</h2>
				</div>
				<?php if(isset($oldplugintest)): ?>
					<div class="clear"></div>
					<div class="itw_issue">
						<p>
						This plugin is a newer version of <b>InstaPost Press</b> which has been discontinued.</p>
						<p>Please deactivate and delete <b>InstaPost Press</b> <a href="<?php echo itw_pluginsURL().'#instapost-press' ?>">here</a>.
						</p>
						<p>	Once done you can configure the settings of this plugin and begin to use it!				
						</p>
					</div>
				
				<?php else: ?>
				<?php if(isset($loginUrl)): ?>
				
				<div class="clear"></div>
				<div class="<?php echo $msg_class ?>">
				<p>
				<?php echo $msg ?>
				<?php if ($loginUrl != 'hide'): ?>
				<a href="<?php echo $loginUrl; ?>">Log in</a>
				<iframe id="logoutframe" src="https://instagram.com/accounts/
logout/" width="0" height="0"></iframe>
				<?php endif; ?>
				</p></div>
				
				<?php else: ?>
					<div class="loggedin">
						<div class="itw_connected">
							<p>
								Connected to Instagram as <span><?php echo $msg; ?></span>
								
							</p>
						</div>
						<div class="logout">
							<form name="itw_logout" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
									<input type="hidden" name="itw_logout" value="Y">
									
									
									<input type="submit" class="button" value="Log out" name="logout" onclick="" >
									</form>
									
									 
						</div>
					</div>
					<div class="clear"></div>
				
					<!-- BEGIN ipp_content_left -->
					<div id="ipp_content_left" class="postbox-container">
						
						<!-- BEGIN metabox-holder -->
						<div class="metabox-holder">
						
							<!-- BEGIN meta-box-sortables ui-sortable -->
							<div class="meta-box-sortables ui-sortable">
							
				
								<form name="itw_form" method="post" autocomplete="off" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
								<input type="hidden" name="itw_hidden" value="Y">
						
								
								<!-- BEGIN wordpress -->
								<div id="wordpress" class="postbox">
								
									<div class="handlediv" title="Click to toggle">
										<br>
									</div>
						
									<?php echo "<h3 class='hndle'><span>" . __( 'Settings', 'itw_trdom' ) . "</span></h3>"; ?>
									
									<!-- BEGIN inside -->
									<div class="inside">
										<h4>Last Instagram Image</h4>
										
										<p class="itw_info">All Images after this image will get auto posted. Select to retrospectively post images from your feed.</p>
										
										<p><label class="textinput">Last Image:</label>
										<?php 
										
										if (isset($_POST['itw_manuallstid']))
										{
										$manuallstid = $_POST['itw_manuallstid'];
										}
										
										foreach($feed->data as $item):
										
										$title = (isset($item->caption->text)?filter_var($item->caption->text, FILTER_SANITIZE_STRING):"");
										$title = itw_truncateString($title,80);
										$id = $item->id;
										
										$selected = '';					
										
										if ( $manuallstid == $id ) {
											$selected = "selected='selected'"; 
										  }
										 								
										$options[] = "<option value='{$id}' $selected >{$title}</option>";
										
										endforeach; ?>
										
										<select name="itw_manuallstid" class="img_select">
										<?php echo implode("\n", $options); ?>
										</select>
										</p>
										<h4>WordPress Post</h4>
										
										<p class="itw_info">Default WordPress post settings</p>
										
										<p><label class="textinput">Image Size:</label><input type="text" name="itw_imagesize" value="<?php echo $imagesize; ?>" ></p>
										
										<p><label class="textinput">Image CSS Class:</label><input type="text" name="itw_imageclass" value="<?php echo $imageclass; ?>" ></p>
							
										<p><input type="checkbox" name="itw_imagelink" <?php if ($imagelink ==true) { echo 'checked="checked"'; } ?> /> Wrap Image in Link to Image
										</p>
										
										<p class="itw_info">Configure how the image is stored and presented</p>
										
										<p><label class="textinput">Select Image Saving:</label>
											<select name="itw_imagesave">  
												<option <?php if ($imagesave == 'link') { echo 'selected="selected"'; } ?> value="link">Link to Instagram Image</option>
												<option <?php if ($imagesave == 'save') { echo 'selected="selected"'; } ?> value="save">Save Image to Media Library</option>
											</select>  
										 </p>
										 
										 <p><label class="textinput">Featured Image Config:</label>
											<select name="itw_imagefeat">  
												<option <?php if ($imagefeat == 'nofeat') { echo 'selected="selected"'; } ?> value="nofeat">No Featured Image</option>
												<option <?php if ($imagefeat == 'featand') { echo 'selected="selected"'; } ?> value="featand">Featured and Post Image</option>
												<option <?php if ($imagefeat == 'featonly') { echo 'selected="selected"'; } ?> value="featonly">Featured Only</option>
											</select>  
										 </p>
										
										<p><label class="textinput">Post Category:</label>
						
										 <?php $args = array(
										
										
										'selected'                => $postcats,
										'include_selected'        => true,
										'hide_empty'			  => 0,
										'orderby'				  => 'name',
										'order'					  => 'ASC',
										'name'                    => 'itw_postcats'
										);
										
										wp_dropdown_categories( $args ); ?> 
										</p>
										<p><label class="textinput">Post Author:</label>
										<?php $args = array(
										
										
										'selected'                => $postauthor,
										'include_selected'        => true,
										'name'                    => 'itw_postauthor'
										
										); 
										 wp_dropdown_users( $args ); ?> </p>
										 
										<p><label class="textinput">Post Format:</label> 
										<?php 
										$output = '<select class="pvw-input" name="itw_postformat">';
		
										if ( current_theme_supports( 'post-formats' ) ) {
											
											$post_formats = get_theme_support( 'post-formats' );
											if ( is_array( $post_formats[0] ) ) {
										
												$output .= '<option value="0">Standard</option>';
												$select_value = $postformat;
												 
												foreach ($post_formats[0] as $option) {
													
													$selected = '';
													
													 if($select_value != '') {
														 if ( $select_value == $option) { $selected = ' selected="selected"';} 
													 } else {
														 if ( isset($value['std']) )
															 if ($value['std'] == $option) { $selected = ' selected="selected"'; }
													 }
													  
													 $output .= '<option'. $selected .'>';
													 $output .= $option;
													 $output .= '</option>';
												 
												 } 
												 
											
											}
											
											else
											{
											
												$output .= '<option>';
												$output .= 'Standard';
												$output .= '</option>';
										
											}
										 
										}
										else
										{
											
											$output .= '<option>';
											$output .= 'Standard';
											$output .= '</option>';
										
										}
										
										$output .= '</select></p>'; 
										 
										echo $output; 
										?> 
										 
										 <p><label class="textinput">Post Date:</label>
											<select name="itw_post_date">  
												<option <?php if ($postdate == 'now') { echo 'selected="selected"'; } ?> value="now">Date at Posting</option>
												<option <?php if ($postdate == 'instagram') { echo 'selected="selected"'; } ?> value="instagram">Instagram Image Created Date</option>
											</select>  
										 </p>
										 
										  <p><label class="textinput">Post Status:</label>
											<select name="itw_poststatus">  
												<option <?php if ($poststatus == 'publish') { echo 'selected="selected"'; } ?> value="publish">Publish</option>
												<option <?php if ($poststatus == 'draft') { echo 'selected="selected"'; } ?> value="draft">Draft</option>
											</select>  
										 </p>
										 
										 <p class="itw_info">If the below custom text fields are left blank, only the Instagram text and image will be used in your post. To position the Instagram data with your custom text use the syntax %%title%% and %%image%%. The %%image%% text cannot be used in the Custom Title Text, and if it doesn't appear in the Body Text the Image will appear at the end of the post body.</p>
										<p><label class="textinput">Custom Title Text:</label><input type="text" class="body_title" name="itw_customtitle" value="<?php echo $customtitle; ?>" > <small>eg. %%title%% - from Instagram</small></p>
										
										<p><label class="textinput">Custom Body Text:</label><textarea class="body_text" rows="10" name="itw_customtext" ><?php echo $customtext; ?></textarea> <small>eg. Check out this new image %%image%% from Instagram</small></p>
										 
										<h4>Plugin Link</h4>
									
										<p class="itw_info">This will place a small link for the plugin at the bottom of the post content, eg. <small>Posted by <a href="http://wordpress.org/extend/plugins/instagrate-to-wordpress/">Instagrate to WordPress</a></small> </p>
										<p><input type="checkbox" name="itw_pluginlink" <?php if ($pluginlink ==true) { echo 'checked="checked"'; } ?> /> Show plugin link 
										 </p>
										
										<h4>Debug Mode</h4>
									
										<p class="itw_info">This is off by default and should only be turned on if you have a problem with the plugin and have contacted us via the <a href="http://www.polevaultweb.com/support/forum/instagrate-to-wordpress-plugin/">Support Forum.</a>
										We will as you to send us the debug.txt file it creates in the plugin folder.</p>
										<p><input type="checkbox" name="itw_debugmode" <?php if ($debugmode ==true) { echo 'checked="checked"'; } ?> /> Enable Debug Mode 
										 </p>
										
										<p class="submit">
								<input type="submit" class="button-primary" name="Submit" value="<?php _e('Update Options', 'ipp_trdom' ) ?>" />
							
								</p>
								</form>
										
										
						 			<!-- END inside -->
						 			</div>
						
								<!-- END wordpress -->
								</div>
								
														
							
								
							<!-- END meta-box-sortables ui-sortable -->
							</div>		
					
						<!-- END metabox-holder -->
						</div>
				
					<!-- END ipp_content_left -->
					</div>
					
					<!-- BEGIN ipp_content_right -->
					<div id="ipp_content_right" class="postbox-container">
					
						<!-- BEGIN metabox-holder -->
						<div class="metabox-holder">	
						
							<!-- BEGIN meta-box-sortables ui-sortable -->
							<div class="meta-box-sortables ui-sortable">
							
								<!-- BEGIN images -->
								<div id="images" class="postbox">
								
									<div class="handlediv" title="Click to toggle">
									<br>
									</div>
										
									<h3 class='hndle'><span>Instagram Feed -<small> Most recent at top</small></span></h3>
										
										<!-- BEGIN inside -->
										<div class="inside">
											
											<?php foreach($feed->data as $item): ?>
											<?php $title = (isset($item->caption->text)?filter_var($item->caption->text, FILTER_SANITIZE_STRING):"");
												  $title = itw_truncateString($title,80);
										
										?>
												
												<div class="image_left">
													<a class="feed_image" href="#">
														<span class="overlay">
															<span class="caption">
																<?php echo $title ?><br/>
																
															</span>
														</span>
														<img src="<?php echo $item->images->thumbnail->url; ?>" alt="<?php echo $title ?>" /><br />
													</a>
												</div>
												
											<?php endforeach; ?>
											
											<div class="clear"></div>
										<!-- END inside -->
										</div>
										
								<!-- END images -->	
								</div>
								
							<!-- END meta-box-sortables ui-sortable -->
							</div>	
						
						<!-- END metabox-holder -->
						</div>
						
					<!-- END ipp_content_right -->	
					</div>

					
					
				<?php endif; ?>
				
				
				
				<div class="clear"></div>
				<!-- BEGIN Footer -->
				<div id="itw_footer">
				
				
					<div id="links">
						<b>Instagrate to WordPress</b> | We hope you enjoy the plugin | 
						<a href="http://www.polevaultweb.com/support/forum/instagrate-to-wordpress-plugin/">Support Forum</a> |
						<a title="Donate" href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=R6BY3QARRQP2Q">Donate</a> |
						<a title="Follow on Twitter" href="http://twitter.com/#!/polevaultweb">@polevaultweb</a> |
						<a href="http://www.polevaultweb.com/plugins/instagrate-to-wordpress/">Plugin Site</a> |
						<a href="http://wordpress.org/extend/plugins/instagrate-to-wordpress/" title="Rate the Plugin on WordPress">Rate the Plugin ★★★★★</a> |
						<a href="http://led24.de/iconset/">16px Icons</a>
					</div>
					
					<div id="pvw">
					
						<a id="logo" href="http://www.polevaultweb.com/" title="Plugin by Polevaultweb" target="_blank"><img src="<?php echo plugins_url('',__FILE__); ?>/images/polevaultweb_logo.png" alt="polevaultweb logo" width="120" /></a>
					
					</div>
				
	
				
				</div>
				<!-- END Footer -->
				<div class="clear"></div>
				
				<?php endif; ?>
			
			<!-- END Wrap -->
			</div>
			<?php
			
				
		}
		
	}
	
}

if (class_exists("instagrate_to_wordpress")) {

	// Load plugin
	instagrate_to_wordpress::load_plugin();
	
}

?>